package org.gcube.portlets.user.geoportaldataviewer.shared.gis;

import java.io.Serializable;

import org.gcube.application.geoportalcommon.shared.products.BaseConcessioneDV;
import org.gcube.portlets.user.geoportaldataviewer.shared.cl.document.materialization.GCubeSDILayerDV;


/**
 * Represents a layer, 
 *  holds the layer item and the related Collection info if existing
 * 
 * 
 */
public class LayerObject implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = -2282478701630148774L;
	
	
	public static enum LayerObjectType{
		BASE_LAYER,
		PROJECT_LAYER,
		INDEX_LAYER,
		GENERIC_LAYER
	}
	
	
	private LayerObjectType type;
	
	private IndexLayer indexLayer; 			// expected for INDEX_LAYER type
	private String ucid;           			// expected for collection layers
	private GCubeSDILayerDV projectLayer;	// expected for PROJECT_LAYER
	private String projectId;      			// expected for PROJECT_LAYER

	private LayerItem layerItem;

	
	

	public LayerObject() {
		super();
	}

	public LayerObject(LayerObjectType type,LayerItem item) {
		this.setType(type);
		this.setLayerItem(item);
	}
	
	
	public LayerObject(String ucid, IndexLayer indexLayer, LayerItem item) {
		this(LayerObjectType.INDEX_LAYER,item);
		this.ucid=ucid;
		this.indexLayer=indexLayer;
	}
	
	public LayerObject(String ucid, String projectId, GCubeSDILayerDV projectLayer, LayerItem item) {
		this(LayerObjectType.PROJECT_LAYER,item);
		this.ucid=ucid;
		this.projectId=projectId;
		this.projectLayer = projectLayer;
	}

	
	public LayerObjectType getType() {
		return type;
	}


	public void setType(LayerObjectType type) {
		this.type = type;
	}


	public IndexLayer getIndexLayer() {
		return indexLayer;
	}


	public void setIndexLayer(IndexLayer indexLayer) {
		this.indexLayer = indexLayer;
	}


	public String getUcid() {
		return ucid;
	}


	public void setUcid(String ucid) {
		this.ucid = ucid;
	}


	public GCubeSDILayerDV getProjectLayer() {
		return projectLayer;
	}


	public void setProjectLayer(GCubeSDILayerDV projectLayer) {
		this.projectLayer = projectLayer;
	}


	public String getProjectId() {
		return projectId;
	}


	public void setProjectId(String projectId) {
		this.projectId = projectId;
	}


	public LayerItem getLayerItem() {
		return layerItem;
	}


	public void setLayerItem(LayerItem layerItem) {
		this.layerItem = layerItem;
	}


	public static long getSerialversionuid() {
		return serialVersionUID;
	}
	
	
	
	

}